@@ -200,7 +200,7 @@ makeRweaveSphinxCodeRunner <- function(evalFunc=RweaveEvalWithOpt)
                         linesout[thisline + 1L] <- srcline
                         thisline <- thisline + 1L
                     }
-                    if(options$results=="sphinx"){
+                    if(options$results=="ascii"){
                         if(openSinput){
                             cat("",
                                 file=chunkout, append=TRUE)
@@ -421,7 +421,7 @@ RweaveSphinxOptions <- function(options)
     if(!is.null(options$results))
         options$results <- tolower(as.character(options$results))
     options$results <- match.arg(options$results,
-                                 c("verbatim", "sphinx", "hide"))
+                                 c("verbatim", "ascii", "hide"))
 
     if(!is.null(options$strip.white))
         options$strip.white <- tolower(as.character(options$strip.white))
